@@ -114,6 +114,14 @@ class UCubeClientSync(UCubeClient):
                             post.comments = self.fetch_post_comments(post.slug)
 
             self.cache_loaded = True
+            if self.verbose:
+                print("UCube Client Cache is now fully loaded.")
+
+            if self._hook:
+                if self.verbose:
+                    print("UCube Client is now starting to check for new notifications.")
+                self._start_loop_for_hook()
+
         except Exception as err:
             if self._own_session:
                 self.web_session.close()
@@ -138,8 +146,8 @@ class UCubeClientSync(UCubeClient):
             The client's login payload
         """
         with self.web_session.post(url=self._auth_login_url, json=login_payload) as resp:
-            if self._check_status(resp.status_code, self._auth_login_url):
-                data = json.loads(resp.text)
+            data = json.loads(resp.text)
+            if self._check_status(resp.status_code, self._auth_login_url, message=data.get("message")):
                 refresh_token = data.get("refresh_token")
                 token = data.get("token")
                 if refresh_token:
@@ -244,7 +252,8 @@ class UCubeClientSync(UCubeClient):
         }
         url = self.replace(self._notifications_url, **replace_kwargs)
         with self.web_session.get(url=url, headers=self._headers) as resp:
-            if self._check_status(resp.status_code, url):
+            data = json.loads(resp.text)
+            if self._check_status(resp.status_code, url, message=data.get("message")):
                 data = json.loads(resp.text)
                 for raw_notification in data.get("items"):
                     notification = create_notification(raw_notification)
@@ -420,9 +429,9 @@ class UCubeClientSync(UCubeClient):
         Refresh a token while logged in.
         """
         payload = {"refresh_token": self._get_refresh_token()}
-        with self.web_session.post(url=self._auth_login_url, json=payload) as resp:
-            if self._check_status(resp.status_code, self._auth_login_url):
-                data = json.loads(resp.text)
+        with self.web_session.post(url=self._refresh_auth_url, json=payload) as resp:
+            data = json.loads(resp.text)
+            if self._check_status(resp.status_code, self._refresh_auth_url, message=data.get("message")):
                 token = data.get("token")
                 if token:
                     self._set_token(token)
